@@ -2,6 +2,7 @@
 # Configuration file for using the xslt library
 #
 XSLT_LIBDIR="-L/usr/lib"
-XSLT_LIBS="-lxslt -lxml2  -lm "
+XSLT_LIBS="-lxslt -lxml2 "
+XSLT_PRIVATE_LIBS="-lm"
 XSLT_INCLUDEDIR="-I/usr/include"
-MODULE_VERSION="xslt-1.1.33"
+MODULE_VERSION="xslt-1.1.41"
